pub enum CommandError {
Failure {
code: CommandErrorCode,
text: String,
},
MalformedResponse(String),
IoError(Error),
SerializeError(SerializeError),
}Expand description
Errors that can occur when sending commands.
Variants
Failure
The command failed.
MalformedResponse(String)
The command’s response was malformed and could not be parsed.
IoError(Error)
A general IOError occurred.
SerializeError(SerializeError)
The command could not be serialized into a RawCommand.
Implementations
Sourceimpl CommandError
impl CommandError
Sourcepub fn from_message(msg: impl AsRef<str>) -> Self
pub fn from_message(msg: impl AsRef<str>) -> Self
Parse a CommandError from a response message.
Sourcepub fn response_missing_field(name: impl AsRef<str>) -> Self
pub fn response_missing_field(name: impl AsRef<str>) -> Self
Create a MalformedResponse error for a missing field.
Sourcepub fn response_incorrect_data_type(
expected_type: impl AsRef<str>,
actual_value: impl Debug,
) -> Self
pub fn response_incorrect_data_type( expected_type: impl AsRef<str>, actual_value: impl Debug, ) -> Self
Create a MalformedResponse error for mismatched data types.