pub enum CommandErrorCode {
Show 18 variants
UnrecognizedCommand,
InvalidId,
InvalidArguments,
DataNotAvailable,
ResourceNotAvailable,
InvalidCredentials,
CommandNotExecuted,
UserNotLoggedIn,
ParamOutOfRange,
UserNotFound,
InternalError,
SystemError(i64),
ProcessingPreviousCommand,
CannotPlay,
NotSupported,
CommandQueueFull,
SkipLimit,
Unknown(i64),
}Expand description
Error codes for when a command fails.
Variants
UnrecognizedCommand
The command was not recognized as a valid HEOS command.
InvalidId
One or more of the IDs specified in the command was not valid.
InvalidArguments
One or more command arguments were missing or not valid.
DataNotAvailable
The requested data was not available.
ResourceNotAvailable
The requested resource was not currently available.
InvalidCredentials
The specified credentials were not valid.
CommandNotExecuted
The command could not be executed.
UserNotLoggedIn
There is no logged-in user when one is required.
ParamOutOfRange
One or more of the specified parameters were out of valid range.
UserNotFound
A user was not found.
InternalError
An internal error occurred.
SystemError(i64)
A system error occurred (this is usually in regard to an external music service).
ProcessingPreviousCommand
The system was busy processing a previous command.
CannotPlay
The specified media could not be played.
NotSupported
An option was specified that is not supported by the relevant music service.
CommandQueueFull
The system command queue is full, and cannot process more commands.
SkipLimit
The user’s skip limit was reached (this is music service specific).
Unknown(i64)
An unknown/unrecognized error occurred.