pub struct Artist {
pub name: String,
pub container_id: String,
pub playable: bool,
pub image_url: Option<Url>,
pub media_id: Option<String>,
}Expand description
Information about an artist.
Fields
name: StringName of the artist.
container_id: StringID representing the artist’s “container” (all music by said artist).
playable: boolIs the artist directly playable?
image_url: Option<Url>URL to an image representing the artist, if it exists.
If this is None, it may be able to be retrieved via the
GetAlbumMetadata command.
media_id: Option<String>Media ID of this artist, if it’s playable.