pub enum SourceAvailable {
True,
False,
}Expand description
Status of source availability.
Variants
True
The source is available to play from.
For music services, this means that an account is logged-in and associated with the music service for it to be usable.
False
The source is NOT available to play from.