AdHoc

Struct AdHoc 

pub struct AdHoc { /* private fields */ }
Inner state for a HeosConnection object that is actively connected to a HEOS endpoint, but does not manage any state.

AdHoc connections can be used to send commands and receive responses, but do no tracking of the HEOS system’s state.