pub struct MoveQueue {
pub player_id: PlayerId,
pub src_queue_ids: Vec<QueueId>,
pub dst_queue_id: QueueId,
}Expand description
Move songs around in a queue.
use heos::HeosConnection;
use heos::command::player::MoveQueue;
use heos::data::player::PlayerId;
use heos::data::queue::QueueId;
use std::time::Duration;
let heos = HeosConnection::connect_any(Duration::from_secs(1)).await?;
heos.command(MoveQueue {
player_id: PlayerId::from(42),
src_queue_ids: vec![QueueId::from(3), QueueId::from(4)],
dst_queue_id: QueueId::from(1),
}).await?;Fields
player_id: PlayerIdID of the player to move queued songs on.
src_queue_ids: Vec<QueueId>One or more IDs of queued songs to move.
dst_queue_id: QueueIdID of the destination queued song to move the src songs to.
The songs will be inserted right before the destination.