pub struct Container {
pub name: String,
pub container_id: String,
pub playable: bool,
pub image_url: Option<Url>,
pub media_id: Option<String>,
}Expand description
Information about a generic music container.
Fields
name: StringName of the container.
container_id: StringID of the container.
playable: boolIs the container directly playable?
image_url: Option<Url>URL to an image representing the container, if it exists.
If this is None, it may be able to be retrieved via the
GetAlbumMetadata command.
media_id: Option<String>Media ID of this container, if it’s playable.