Stateful management of a connected HEOS system.
Whereas the data module deals with pure data at an instant in time, this module contains the logic necessary to maintain a stateful connection to a HEOS system, and keep it updated in real time using events that are output from said HEOS system.
Most of the types in this module provide “views” into the state without providing ownership over it. The ownership of all state belongs to the top-level HeosConnection, and these views can be retrieved from a stateful instance of that connection.
Modules
- group
- Stateful group management.
- playable
- Abstraction around anything stateful that can play music.
- player
- Stateful player management.
- source
- Stateful source management.
Structs
- State
- State that is managed in a stateful HeosConnection.